(sec_trees)=

# Trees page

![Trees Page](tsbrowse:example.tsbrowse:trees)
A tree sequence generally consists of multiple highly correlated genetic genealogies along the sequence, referred to as trees. This page summarises the individual trees in a tree sequence. The histograms show the distribution of various aspects of the trees, including the number of sites and mutations in each tree, the genomic span (i.e., the length of sequence the tree spans), the total branch length (i.e., the total sum of branch lengths over all samples in the tree, in time units), and the arity (i.e., the number of children nodes in the tree have).

## Plot controls (sidebar):
* The `log y-axis` checkbox plots the number of trees on the log scale.